.. _guilty:

.. raw:: html

  <br><br>


.. title:: Guilty


.. raw:: html

    <center><b>GUILTY</b></center><br>


.. _informed:


**INFORMED**

.. raw:: html

    <br>

.. image:: informed.jpg
    :width: 100%

.. raw:: html

    <br>

.. _chamber:

**CHAMBER**

.. raw:: html

    <br>

.. image:: kamer2.png
    :width: 100%

.. raw:: html

    <br>

.. _king:


**KING**


.. raw:: html

    <br>

.. image:: bevestigd.jpg
    :width: 100%

.. raw:: html

  <br>
